Attribute VB_Name = "Callback"
'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
'   Global declarations used throughout the NTFYSAMP project
Global CallbackFlag As Boolean
Global DeviceError As Boolean
Global RefData As Variant
Global ReadingsArray(100) As Double
Global ReadingsTaken As Integer
Global NumberOfReadings As Integer
Global ErrorMessage As String


'  In this example, this is the user-defined callback where the
'  measurements are read back from the Fluke 45.
Public Function DevCallback(ByVal ud As Long, ByVal LocalIbsta As Long, ByVal LocalIberr As Long, ByVal LocalIbcntl As Long, ByRef RefData As Variant) As Long

    Dim LocalIbstaVar As Integer

    LocalIbstaVar = CInt(LocalIbsta)
    
    '  If the EERR bit is set in LocalIbsta, then set
    '  DeviceError to TRUE and return.
    If (LocalIbstaVar And EERR) Then
       DeviceError = True
       DevCallback = 0
       Exit Function
    End If
      
    '  If the returned status byte is &H50 then the Fluke
    '  45 has valid data to send
    LocalIbstaVar = ilrsp(ud, SPollByte%)
    If (LocalIbstaVar And EERR) Then
        ErrorMessage = "Error serial polling the device."
        DeviceError = True
        DevCallback = 0
        Exit Function
    End If
    If (SPollByte% <> &H50) Then
        ErrorMessage = "Serial poll byte is NOT &H50."
        DeviceError = True
        DevCallback = 0
        Exit Function
    End If
    
    '  Read the Fluke 45 measurement.
    rdbuf$ = Space$(10)
    LocalIbstaVar = ilrd(ud, rdbuf$, Len(rdbuf$))
    If (LocalIbstaVar And EERR) Then
        ErrorMessage = "Error reading from device."
        DeviceError = True
        DevCallback = 0
        Exit Function
    End If
    ReadingsTaken = ReadingsTaken + 1
    ReadingsArray(ReadingsTaken) = Val(rdbuf$)
    
    If (ReadingsTaken = NumberOfReadings) Then
        CallbackFlag = True
       '  Do not rearm the callback.
        DevCallback = 0
    Else
        '  Trigger the Fluke 45.
        LocalIbstaVar = iltrg(ud)
        If (LocalIbstaVar And EERR) Then
            ErrorMessage = "Error triggering device."
            DeviceError = True
            DevCallback = 0
            Exit Function
        End If
      
        '  Request the triggered measurement by sending VAL1?
        wrtbuf$ = "VAL1?"
        LocalIbstaVar = ilwrt(ud, wrtbuf$, Len(wrtbuf$))
        If (LocalIbstaVar And EERR) Then
            ErrorMessage = "Error writing to device."
            DeviceError = True
            DevCallback = 0
            Exit Function
        End If
        
        CallbackFlag = True
        
        '  Rearm the callback with RQS event.
        DevCallback = RQS
    End If
    
End Function
